<img src="timechart_launcher/icons/charts_128.png" width="128" height="128" align="right"/>
  <h1>TimeChart</h1>
  <h3>A Charting Tool based on PyDM</h3>
</p>

TimeChart is a Python Qt-based graphing application for control systems.
It is intended to be the modern, feature-by-feature matching alternative
to the Motif [EPICS Strip Tool](https://epics.anl.gov/extensions/StripTool/ "EPICS Strip Tool") application.

Comparing with Strip Tool, TimeChart possesses the inherent cross-platform,
responsive, and regularly maintained and supported advantages offered by
[Python Display Manager (PyDM)](https://github.com/slaclab/pydm "PyDM").
As a Python Qt-based framework, PyDM is also created and maintained by SLAC.
Its charting capability is built upon [pyqtgraph](http://pyqtgraph.org/ "PyQtGraph"),
and the PyDM's TimePlot is the central widget in TimeChart.

# Installing and Running TimeChart

Refer to [TimeChart Documentation] (https://slaclab.github.io/timechart/ "TimeChart Documentation") for detailed
instructions on how to install and run TimeChart.

# Acknowledgements

Icons made by [monkik](https://www.flaticon.com/authors/monkik) from [www.flaticon.com](https://www.flaticon.com/) is
licensed by [CC 3.0 BY](http://creativecommons.org/licenses/by/3.0/).
